__version__ = "0.0.4"
__description__ = "Python client for interfacing with NTCore"
__license__ = "Apache 2.0"
__maintainer__ = "NTCore"
__maintainer_email__ = "info@nantutech.com"
__title__ = "ntcore"
__url__ = "https://www.nantu.io/"